pub struct OspfNetwork {
pub prefix: IpNet,
pub wildcard: bool,
}Expand description
A network <addr> <wildcard> area <id> statement.
Fields
prefix: IpNetThe network prefix. If the config used a wildcard mask, it is converted to prefix length.
wildcard: boolTrue if the original config used a wildcard mask (not prefix length).